@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cheapskate
-version: 0.1.0.4
-id: cheapskate-0.1.0.4-3bca36ddfca79c352f8e4daae1c4e533
-key: cheap_CVH5scrcse27LeQNUCgbqZ
+version: 0.1.0.5
+id: cheapskate-0.1.0.5-6650c88db577f6af6e10e8b013bfd5bc
+key: cheap_8GyTDdKDxkR9TVf2IY0Wz6
 license: BSD3
 copyright: (C) 2012-2013 John MacFarlane
 maintainer: jgm@berkeley.edu
@@ -28,20 +28,20 @@ exposed-modules:
 hidden-modules: Cheapskate.Util Cheapskate.Inlines
                 Cheapskate.ParserCombinators Paths_cheapskate
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
-library-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
-data-dir: /usr/share/arm-linux-ghc-7.10.3/cheapskate-0.1.0.4
-hs-libraries: HScheapskate-0.1.0.4-CVH5scrcse27LeQNUCgbqZ
+import-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.5
+library-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.5
+data-dir: /usr/share/arm-linux-ghc-7.10.3/cheapskate-0.1.0.5
+hs-libraries: HScheapskate-0.1.0.5-8GyTDdKDxkR9TVf2IY0Wz6
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
+    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
+    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     uniplate-1.6.12-474087ddfa30ffe8f83d021d3c4c23e6
-    xss-sanitize-0.3.5.6-f78b5b03aa1efe6d65b9961065a15c78
+    xss-sanitize-0.3.5.7-6c3c3bcb4d13c9ca0347038667ddbff4
 haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
 haddock-html: /usr/share/doc/haskell-cheapskate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
